==> koffice-1.3.5.tar.bz2: koffice-1.3.5/filters/kword/wordperfect/export/wp6.h <==
/* This file is part of the KDE project
   Copyright (C) 2002 Ariya Hidayat <ariya@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
*/

#ifndef __WP6_H
#define __WP6_H

#include <KWEFStructures.h>
#include <KWEFBaseWorker.h>

class QString;
class QFile;
class QDataStream;

class WPSixWorker : public KWEFBaseWorker
{
  public:
    WPSixWorker(void)  { }
    virtual ~WPSixWorker(void) { }
    virtual bool doOpenFile(const QString& filenameOut, const QString& to);
    virtual bool doCloseFile(void);
    virtual bool doOpenDocument(void);
    virtual bool doCloseDocument(void);
    virtual bool doFullParagraph(const QString& paraText, const LayoutData& layout,
        const ValueListFormatData& paraFormatDataList);
  private:
    QString filename;
    QFile outfile;
    QDataStream output;
    Q_UINT32 document_area_ptr;
};

#endif //__WP6_H

==> koffice-1.6.3.tar.bz2: koffice-1.6.3/filters/kword/wordperfect/export/wp6.h <==
/* This file is part of the KDE project
   Copyright (C) 2002 Ariya Hidayat <ariya@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef __WP6_H
#define __WP6_H

#include <KWEFStructures.h>
#include <KWEFBaseWorker.h>

class QString;
class QFile;
class QDataStream;

class WPSixWorker : public KWEFBaseWorker
{
  public:
    WPSixWorker(void)  { }
    virtual ~WPSixWorker(void) { }
    virtual bool doOpenFile(const QString& filenameOut, const QString& to);
    virtual bool doCloseFile(void);
    virtual bool doOpenDocument(void);
    virtual bool doCloseDocument(void);
    virtual bool doFullParagraph(const QString& paraText, const LayoutData& layout,
        const ValueListFormatData& paraFormatDataList);
  private:
    QString filename;
    QFile outfile;
    QDataStream output;
    Q_UINT32 document_area_ptr;
};

#endif //__WP6_H
